@@ -1,25 +1,16 @@
-from cgi import parse_header
 from copy import copy
 from io import BytesIO
-from typing import Any
-from typing import Dict
-from typing import Optional
-from typing import Tuple
-from typing import Union
+from typing import Any, Dict, Optional, Union
 
-from .http_cookies import HttpCookieJar
-from .http_cookies import parse_cookie_header
+from .http_cookies import HttpCookieJar, parse_cookie_header
 from .http_headers import HttpHeaders
-from .http_message import FormHttpMessage
-from .http_message import HttpMessage
-from .http_message import JsonHttpMessage
-from .http_message import MultipartHttpMessage
 from .http_method import HttpMethod
+from .http_parsed_body import HttpParsedBodyTrait
 from .http_query_string import HttpQueryString
 from .routing import Route
 
 
-class HttpRequest:
+class HttpRequest(HttpParsedBodyTrait):
     def __init__(
         self,
         method: Union[HttpMethod, str],
@@ -44,49 +35,23 @@ class HttpRequest:
         self.path = path
         self.query_string = query_string
         self.path_parameters: Dict[str, str] = {}
-        self.headers = headers if headers else HttpHeaders()
         self.route: Optional[Route] = None  # type: ignore
         self.attributes: Dict[str, Any] = {}
-        self._body = body if body else BytesIO(b"")
-        self._parsed_body: Optional[HttpMessage] = None
+        self._headers = headers if headers else HttpHeaders()
         self._cookies: Optional[HttpCookieJar] = None
+        self._body = body if body else BytesIO(b"")
+        self._parsed_body = None
+        self._as_dict = None
+        self._as_str = None
 
     @property
     def body(self) -> BytesIO:
         return copy(self._body)
 
-    @property
-    def parsed_body(self) -> HttpMessage:
-        if self._parsed_body:
-            return copy(self._parsed_body)
-
-        content_type: Tuple[str, Dict[str, str]] = parse_header(
-            self.headers["Content-Type"]  # type: ignore
-        )
-
-        parsed_body: HttpMessage
-
-        if content_type[0] == "multipart/form-data":
-            parsed_body = MultipartHttpMessage.from_bytes(
-                self.body, content_type[1].get("boundary", ""), content_type[1].get("charset", ""),
-            )
-        elif content_type[0] == "application/x-www-form-urlencoded":
-            parsed_body = FormHttpMessage.from_bytes(self.body, content_type[1].get("charset", "utf8"))
-
-        elif content_type[0] == "application/json":
-            parsed_body = JsonHttpMessage.from_bytes(self.body, content_type[1].get("charset", "utf8"))
-        else:
-            self.body.seek(0)
-            parsed_body = HttpMessage(self.body.read().decode(content_type[1].get("charset", "utf8")))
-
-        self._parsed_body = parsed_body
-
-        return copy(self._parsed_body)
-
     @property
     def cookies(self):
         if self._cookies is None:
-            self._cookies = parse_cookie_header(self.headers.get("cookie"))
+            self._cookies = parse_cookie_header(self._headers.get("cookie"))
 
         return copy(self._cookies)
 
@@ -96,11 +61,15 @@ class HttpRequest:
 
         return (
             self.method == other.method
-            and self.headers == other.headers
+            and self._headers == other._headers
             and self.path == other.path
             and self.query_string == other.query_string
             and self.body.getbuffer().nbytes == other.body.getbuffer().nbytes
         )
 
+    @property
+    def headers(self) -> HttpHeaders:
+        return self._headers
+
 
 __all__ = ["HttpRequest"]
